Index: src/sas/dataloader/readers/defaults.json
===================================================================
--- src/sas/dataloader/readers/defaults.json	(revision 5dfdfa7b1103a8dfb020e940cb1e38dcde633256)
+++ src/sas/dataloader/readers/defaults.json	(revision 5dfdfa7b1103a8dfb020e940cb1e38dcde633256)
@@ -0,0 +1,38 @@
+{
+   "SasLoader":{
+      "FileType":[
+         {
+            "-extension":".xml",
+            "-reader":"cansas_reader"
+         },
+         {
+            "-extension":".txt",
+            "-reader":"ascii_reader"
+         },
+         {
+            "-extension":".asc",
+            "-reader":"IgorReader"
+         },
+         {
+            "-extension":".dat",
+            "-reader":"red2d_reader"
+         },
+         {
+            "-extension":".abs",
+            "-reader":"abs_reader"
+         },
+         {
+            "-extension":".d1d",
+            "-reader":"hfir1d_reader"
+         },
+         {
+            "-extension":".sans",
+            "-reader":"danse_reader"
+         },
+         {
+            "-extension":".nxs",
+            "-reader":"nexus_reader"
+         }
+      ]
+   }
+}
Index: c/sas/dataloader/readers/defaults.xml
===================================================================
--- src/sas/dataloader/readers/defaults.xml	(revision fd5ac0db8089df5bd882587f157d4bf317cfcf67)
+++ 	(revision )
@@ -1,21 +1,0 @@
-<?xml version="1.0"?>
-<SasLoader version="1.0"
-    xmlns="sasloader/1.0"
-    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-    >
-	
-	<FileType extension='.xml' reader='cansas_reader'/>
-	<FileType extension='.txt' reader='ascii_reader'/>
-	<FileType extension='.asc' reader='IgorReader'/>
-	<FileType extension='.dat' reader='red2d_reader'/>
-	<!--
-	Removed the tiff_reader for now. To reinstate, remove the XML comment
-	<FileType extension='.tif' reader='tiff_reader'/>
-	-->
-	<FileType extension='.abs' reader='abs_reader'/>
-	<FileType extension='.d1d' reader='hfir1d_reader'/>
-	<FileType extension='.sans' reader='danse_reader'/>
-	<FileType extension='.nxs' reader='nexus_reader'/>
-    
-</SasLoader>
-

Index: src/sas/dataloader/readers/associations.py
===================================================================
--- src/sas/dataloader/readers/associations.py	(revision fd5ac0db8089df5bd882587f157d4bf317cfcf67)
+++ src/sas/dataloader/readers/associations.py	(revision 5dfdfa7b1103a8dfb020e940cb1e38dcde633256)
@@ -17,13 +17,9 @@
 import sys
 import logging
-from lxml import etree
-# Py2exe compatibility: import _elementpath to ensure that py2exe finds it
-from lxml import _elementpath
+import json
 
-## Format version for the XML settings file
-VERSION = 'sasloader/1.0'
+FILE_NAME = 'defaults.json'
 
-
-def read_associations(loader, settings='defaults.xml'):
+def read_associations(loader, settings=FILE_NAME):
     """
     Read the specified settings file to associate
@@ -31,5 +27,5 @@
     
     :param loader: Loader object
     :param settings: path to the XML settings file [string]
     """
     reader_dir = os.path.dirname(__file__)
@@ -47,18 +43,14 @@
         path = "./%s" % settings
     if os.path.isfile(path):
-        tree = etree.parse(path, parser=etree.ETCompatXMLParser())
-        
-        # Check the format version number
-        # Specifying the namespace will take care of the file format version
-        root = tree.getroot()
+        with open(path) as fh:
+            json_tree = json.load(fh)
         
         # Read in the file extension associations
-        entry_list = root.xpath('/ns:SasLoader/ns:FileType',
-                                 namespaces={'ns': VERSION})
+        entry_list = json_tree['SasLoader']['FileType']
 
         # For each FileType entry, get the associated reader and extension
         for entry in entry_list:
-            reader = entry.get('reader')
-            ext = entry.get('extension')
+            reader = entry['-reader']
+            ext = entry['-extension']
             
             if reader is not None and ext is not None:
@@ -31,5 +27,5 @@
     
     :param loader: Loader object
-    :param settings: path to the XML settings file [string]
+    :param settings: path to the json settings file [string]
     """
     reader_dir = os.path.dirname(__file__)